// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT license. See LICENSE file in the project root for full license information.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;

using Microsoft.VisualStudio.TestPlatform.MSTest.TestAdapter.Helpers;

namespace Microsoft.VisualStudio.TestPlatform.MSTestAdapter.UnitTests.TestableImplementations;

/// <summary>
/// A testable implementation of reflect helper.
/// </summary>
internal class TestableReflectHelper : ReflectHelper
{
    /// <summary>
    /// A dictionary to hold mock custom attributes. The int represents a hash code of
    /// the Type of custom attribute and the level its applied at :
    /// MemberTypes.All for assembly level
    /// MemberTypes.TypeInfo for class level
    /// MemberTypes.Method for method level.
    /// </summary>
    private readonly Dictionary<int, Attribute[]> _customAttributes;

    public TestableReflectHelper()
    {
        _customAttributes = new Dictionary<int, Attribute[]>();
    }

    public void SetCustomAttribute(Type type, Attribute[] values, MemberTypes memberTypes)
    {
        var hashCode = type.FullName.GetHashCode() + memberTypes.GetHashCode();
        _customAttributes[hashCode] = _customAttributes.TryGetValue(hashCode, out Attribute[] value)
            ? value.Concat(values).ToArray()
            : values;
    }

    internal override TAttribute[] GetCustomAttributeForAssembly<TAttribute>(MemberInfo memberInfo)
    {
        var hashCode = MemberTypes.All.GetHashCode() + typeof(TAttribute).FullName.GetHashCode();

        return _customAttributes.TryGetValue(hashCode, out Attribute[] value)
            ? value.OfType<TAttribute>().ToArray()
            : Array.Empty<TAttribute>();
    }

    internal override TAttribute[] GetCustomAttributes<TAttribute>(MemberInfo memberInfo)
    {
        var hashCode = memberInfo.MemberType.GetHashCode() + typeof(TAttribute).FullName.GetHashCode();

        return _customAttributes.TryGetValue(hashCode, out Attribute[] value)
            ? value.OfType<TAttribute>().ToArray()
            : Array.Empty<TAttribute>();
    }
}
